#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 dhall
version:              1.42.3
visibility:           public
id:                   dhall-1.42.3-DRzp8Cw7KB5CC8LwxDhczL
key:                  dhall-1.42.3-DRzp8Cw7KB5CC8LwxDhczL
license:              BSD-3-Clause
copyright:            2017 Gabriella Gonzalez
maintainer:           GenuineGabriella@gmail.com
author:               Gabriella Gonzalez
synopsis:             A configuration language guaranteed to terminate
description:
    Dhall is an explicitly typed configuration language that is not Turing
    complete.  Despite being Turing incomplete, Dhall is a real programming
    language with a type-checker and evaluator.

    Use this library to parse, type-check, evaluate, and pretty-print the Dhall
    configuration language.  This package also includes an executable which
    type-checks a Dhall file and reduces the file to a fully evaluated normal
    form.

    Read "Dhall.Tutorial" to learn how to use this library

category:             Compiler
abi:                  33a4e41a23194c73f19534430051b20f
exposed:              True
exposed-modules:
    Dhall Dhall.Binary Dhall.Context Dhall.Core Dhall.Crypto
    Dhall.Deriving Dhall.Diff Dhall.DirectoryTree Dhall.Format
    Dhall.Freeze Dhall.Import Dhall.Lint Dhall.Main Dhall.Map
    Dhall.Marshal.Decode Dhall.Marshal.Encode Dhall.Optics
    Dhall.Package Dhall.Parser Dhall.Parser.Expression
    Dhall.Parser.Token Dhall.Pretty Dhall.Repl Dhall.Schemas Dhall.Set
    Dhall.Src Dhall.Substitution Dhall.TH Dhall.Tags Dhall.Tutorial
    Dhall.TypeCheck Dhall.Util Dhall.Version

hidden-modules:
    Dhall.DirectoryTree.Types Dhall.Eval Dhall.Import.Types
    Dhall.Import.Headers Dhall.Marshal.Internal Dhall.Normalize
    Dhall.Parser.Combinators Dhall.Pretty.Internal Dhall.Syntax
    Dhall.Syntax.Binding Dhall.Syntax.Chunks Dhall.Syntax.Const
    Dhall.Syntax.Expr Dhall.Syntax.FunctionBinding Dhall.Syntax.Import
    Dhall.Syntax.Instances.Applicative Dhall.Syntax.Instances.Bifunctor
    Dhall.Syntax.Instances.Data Dhall.Syntax.Instances.Eq
    Dhall.Syntax.Instances.Foldable Dhall.Syntax.Instances.Functor
    Dhall.Syntax.Instances.Lift Dhall.Syntax.Instances.Monad
    Dhall.Syntax.Instances.NFData Dhall.Syntax.Instances.Ord
    Dhall.Syntax.Instances.Pretty Dhall.Syntax.Instances.Show
    Dhall.Syntax.Instances.Traversable Dhall.Syntax.MultiLet
    Dhall.Syntax.Operations Dhall.Syntax.RecordField Dhall.Syntax.Types
    Dhall.Syntax.Var Dhall.URL Paths_dhall Dhall.Import.HTTP
    Dhall.Import.Manager

import-dirs:          /usr/lib/ghc-9.6.6/site-local/dhall-1.42.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/dhall-1.42.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/dhall-1.42.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/dhall
hs-libraries:         HSdhall-1.42.3-DRzp8Cw7KB5CC8LwxDhczL
depends:
    Diff-0.5-DbK2KXQffeb9yfLb5gceUe
    aeson-2.2.2.0-E8GnKqfyoqV8B1evVkUtMu
    aeson-pretty-0.8.10-DGsjR3Ta5Yx2N6PF7v6q2G
    ansi-terminal-1.1-7dL9hv2pnhf1UozNlva3HX
    atomic-write-0.2.1.1-4WBeGTWnvbI88dkkfi9dbn base-4.18.2.1
    base16-bytestring-1.0.2.0-48HEWFjAP5dCyfeiVPFVdd
    bytestring-0.11.5.3 case-insensitive-1.2.1.0-Jy8OxWsCrDaBhFbgZ9qrNJ
    cborg-0.2.10.0-GxqOCd9DqLiBJjwarMBqXB
    cborg-json-0.2.6.0-6k5fOSWh85rGm6DUNhDzUQ containers-0.6.7
    contravariant-1.5.6-DrebhAx4XwC59wq9S42cYg
    cryptohash-sha256-0.11.102.1-5Ka3JcLAKZuC60Xjlz2yPS
    data-fix-0.3.4-7RS64eS6UJG1GL0dnQGMU4 deepseq-1.4.8.1
    directory-1.3.8.5 dotgen-0.4.3-A2UTkkV6Fes7fbL6Rpf3sY
    either-5.0.3-1Ok1rjeifLe8j6utAWMh5j exceptions-0.10.7
    filepath-1.4.300.1 half-0.3.3-4fcMpmwReZHDIIiz1iBteV
    hashable-1.4.7.0-IVKAR4D6WU9H8t6zzGQ76p haskeline-0.8.2.1
    http-client-0.7.19-7npayQWK93786YkcsXS9Bz
    http-client-tls-0.3.6.4-AoMgZkRCYiu1L0w7n4Ap42
    http-types-0.12.4-DdbAmHNhx8C4vBT5NO2sZU
    indexed-traversable-0.1.4-8j5HZpShpE5BqFup9Ojenr
    megaparsec-9.7.0-LcQIYWb87vKBQkwIt8CBXH
    microlens-0.4.14.0-IP2Uuhm3qTnDhkfYobH8B3
    microlens-mtl-0.2.1.0-Ewo8HmKpWhTASatFX3KZGS
    mmorph-1.2.2-I879kMQXeoiA7V1mSxl9UH mtl-2.3.1
    network-uri-2.6.4.2-2ifukYXf4pdA7CoyyYtsZ3
    optparse-applicative-0.18.1.0-D1qnF9ppDr4DKTCW01gXle
    parser-combinators-1.3.1-8aQ8dKOwDVmFxT1S1WvW6m
    parsers-0.12.12-5FqlPlH3A3R23U6ECaNhP5
    pretty-simple-4.1.4.0-RC8yN5GskMCKpzemakI1b
    prettyprinter-1.7.1-EN3LFPJyyjtK4N4FJxxajw
    prettyprinter-ansi-terminal-1.1.3-4nWMmaNgO6x2iiKH85gIMw
    repline-0.4.3.0-8K1qOV9c7aG2gqDtsaBJvy
    scientific-0.3.8.1-ABIeDVWgwalJfl71xX5r14
    serialise-0.2.6.1-GttMgHK1ccq7kCR18sfQIX template-haskell-2.20.0.0
    text-2.0.2 text-manipulate-0.3.1.0-1Ehia8Gm9ELBZgN3Etd2LD
    text-short-0.1.6.1-I6PHRM0NmxW2Jd1uGmibgm
    th-lift-instances-0.1.20-5UQXaQXgCBV1VBGvnOMYIW time-1.12.2
    transformers-0.6.1.0 unix-2.8.4.0
    unix-compat-0.7.4.1-BgJ7k18eSblG26Jg0cNHuH
    unordered-containers-0.2.20.1-FX7g4DMKoiaDV91wUmRzTu
    vector-0.13.2.0-E81GJWrGuCo4SgJOIsfBQo

haddock-interfaces:   /usr/share/doc/dhall/html/dhall.haddock
haddock-html:         /usr/share/doc/dhall/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

